TODO
=======================================================================

The following things are known bugs that could use some attention:

- Implement a bulk-insert when inserting a lot of new rockingester records.
- Avoid needing to fetch all rockingester records and matching to all disk files.